@@ -14,12 +14,13 @@ class Command(BaseCommand):
         parser.add_argument(
             "client_type",
             type=str,
-            help="The client type, can be confidential or public",
+            help="The client type, one of: %s" % ", ".join([ctype[0] for ctype in Application.CLIENT_TYPES]),
         )
         parser.add_argument(
             "authorization_grant_type",
             type=str,
-            help="The type of authorization grant to be used",
+            help="The type of authorization grant to be used, one of: %s"
+            % ", ".join([gtype[0] for gtype in Application.GRANT_TYPES]),
         )
         parser.add_argument(
             "--client-id",
@@ -36,6 +37,12 @@ class Command(BaseCommand):
             type=str,
             help="The redirect URIs, this must be a space separated string e.g 'URI1 URI2'",
         )
+        parser.add_argument(
+            "--post-logout-redirect-uris",
+            type=str,
+            help="The post logout redirect URIs, this must be a space separated string e.g 'URI1 URI2'",
+            default="",
+        )
         parser.add_argument(
             "--client-secret",
             type=str,
@@ -49,7 +56,13 @@ class Command(BaseCommand):
         parser.add_argument(
             "--skip-authorization",
             action="store_true",
-            help="The ID of the new application",
+            help="If set, completely bypass the authorization form, even on the first use of the application",
+        )
+        parser.add_argument(
+            "--algorithm",
+            type=str,
+            help="The OIDC token signing algorithm for this application, one of: %s"
+            % ", ".join([atype[0] for atype in Application.ALGORITHM_TYPES if atype[0]]),
         )
 
     def handle(self, *args, **options):
@@ -58,7 +71,7 @@ class Command(BaseCommand):
         application_fields = [field.name for field in Application._meta.fields]
         application_data = {}
         for key, value in options.items():
-            # Data in options must be cleaned because there are unneded key-value like
+            # Data in options must be cleaned because there are unneeded key-value like
             # verbosity and others. Also do not pass any None to the Application
             # instance so default values will be generated for those fields
             if key in application_fields and value:
@@ -77,5 +90,13 @@ class Command(BaseCommand):
             )
             self.stdout.write(self.style.ERROR("Please correct the following errors:\n %s" % errors))
         else:
+            cleartext_secret = new_application.client_secret
             new_application.save()
-            self.stdout.write(self.style.SUCCESS("New application created successfully"))
+            # Display the newly-created client_name or id.
+            client_name_or_id = application_data.get("name", new_application.client_id)
+            self.stdout.write(
+                self.style.SUCCESS("New application %s created successfully." % client_name_or_id)
+            )
+            # Print out the cleartext client_secret if it was autogenerated.
+            if "client_secret" not in application_data:
+                self.stdout.write(self.style.SUCCESS("client_secret: %s" % cleartext_secret))
